import { cn } from '@bem-react/classname';
import React, { useEffect, useState } from 'react';
import { Button, IconButton } from '@mui/material';
import SettingsIcon from '@mui/icons-material/Settings';
import './header.scss';
import { useNavigate } from 'react-router-dom';
import useKeycloakAuth from './keycloak';

const name = cn('Header');

export const Header: React.FC = () => {
    const navigate = useNavigate();

    const {authenticated, keycloak} = useKeycloakAuth();

    return (
        <header className={name()}>
            {authenticated ? <div className={name('Bar')}>
                {!window.location.pathname.includes('/search') ?
                    <Button
                        variant='contained'
                        onClick={() => navigate('/search')}
                    >
                        Search
                    </Button> : <Button
                        variant='contained'
                        onClick={() => navigate('/')}
                    >
                        Back
                    </Button>}
                <div>
                    <Button
                        variant='contained'
                        onClick={() => keycloak.logout()}
                    >
                        Logout
                    </Button>
                    <IconButton
                        sx={{alignSelf: 'center', ml: 2}}
                        onClick={() => document.location = `${process.env.KEYCLOAK_URL}/realms/${process.env.KEYCLOAK_REALM}/account/`}
                    >
                        <SettingsIcon />
                    </IconButton>
                </div>
            </div> : <div className={name('Auth')}>
                <Button
                    variant='contained'
                    onClick={() => keycloak.login()}
                >
                    Login
                </Button>
                <Button
                    sx={{ ml: 2 }}
                    variant='contained'
                    onClick={() => keycloak.register()}
                >
                    Registration
                </Button>
            </div>} 
        </header>
    );
}