import React, { useState } from 'react';
import { Box, Button, InputAdornment, TextField } from '@mui/material';
import { cn } from '@bem-react/classname';

import './createRecord.scss';
import { save } from './server';

const name = cn('CreateRecord');

export const CreateRecord: React.FC = () => {
    const [weight, setWeight] = useState('');
    const [cpg, setCPG] = useState('');
    const [cals, setCals] = useState('');
    const [description, setDescription] = useState('');

    const [errors, setErrors] = useState({weight: false, cpg: false, cals: false});

    const submit = () => {
        // Validation
        if (isNaN(Number(weight)) && weight != '') {
            setErrors(e => ({...e, weight: true}));
        }

        if (isNaN(Number(cpg)) && cpg != '') {
            setErrors(e => ({...e, cpg: true}));
        }

        if (isNaN(Number(cals)) && cals != '') {
            setErrors(e => ({...e, cals: true}));
        }

        if (errors.cals || errors.cpg || errors.weight) {
            return;
        }

        if (weight == '' && cpg == '' && cals == '') {
            setErrors(e => ({...e, cals: true}));
        }

        if (weight != '' && cpg == '' && cals == '') {
            setErrors(e => ({...e, cpg: true}));
        }

        if (weight == '' && cpg != '' && cals == '') {
            setErrors(e => ({...e, weight: true}));
        }

        if (errors.cals || errors.cpg || errors.weight) {
            return;
        }

        let record;

        save({
            calories: Number(cals) || Number(weight) * Number(cpg),
            calspergram: Number(cpg) || null,
            description: description || null,
            weight: Number(weight) || null,
        }).then(() => {
            setWeight('');
            setCPG('');
            setCals('');
        });
    }

    return (
        <div className={name()}>
            <Box 
                sx={{
                    display: 'flex', 
                    flexDirection: 'row', 
                    gap: 2,  // Adjust spacing between inputs
                    alignItems: 'center',  // Align items vertically
                    flexWrap: 'wrap' // Ensure it wraps on smaller screens
                }}
            >
                <TextField 
                    fullWidth
                    error={errors.weight}
                    value={weight}
                    onChange={e => {
                        setWeight(e.target.value);
                        setErrors(e => ({...e, weight: false}))
                    }}
                    variant='outlined'
                    label='Weight'
                    size='small'
                    sx={{ flex: 1, minWidth: '15ch' }}
                    slotProps={{
                        input: {
                            endAdornment: <InputAdornment position="end">g</InputAdornment>,
                        },
                    }}
                    />
                <TextField 
                    error={errors.cpg}
                    value={cpg}
                    onChange={e => {
                        setCPG(e.target.value);
                        setErrors(e => ({...e, cpg: false}));
                    }}
                    variant='outlined'
                    label='Cals per gramm'
                    size='small'
                    sx={{ flex: 1, minWidth: '15ch' }}
                    slotProps={{
                      input: {
                        endAdornment: <InputAdornment position="end">cals</InputAdornment>,
                      },
                    }}
                />
                <TextField 
                    error={errors.cals}
                    value={cals}
                    onChange={e => {
                        setCals(e.target.value);
                        setErrors(e => ({...e, cals: false}));
                    }}
                    variant='outlined'
                    label='Calories'
                    size='small'
                    sx={{ flex: 1, minWidth: '15ch' }}
                    slotProps={{
                      input: {
                        endAdornment: <InputAdornment position="end">cals</InputAdornment>,
                      },
                    }}
                />

            </Box>
            <TextField
                value={description}
                onChange={e => setDescription(e.target.value)}
                variant='standard'
                fullWidth
                placeholder='Description'
                size='small'
                margin='normal'
            />
            <div className={name('Options')}>
                <Button
                    onClick={submit}
                    variant='contained'
                >
                    Save
                </Button>
            </div>
        </div>
    )
}