import { createTheme } from "@mui/material/styles";

const theme = createTheme({
  palette: {
    mode: "dark", // Ensures proper dark mode behavior
    background: {
      default: "#121212",
      paper: "#181818",
    },
    primary: {
      main: "#009999", // Accent Positive
      contrastText: "#f4f4f4", // Ensuring good contrast
    },
    secondary: {
      main: "#444444",
      contrastText: "#f4f4f4",
    },
    error: {
      main: "#FF9640", // Accent Negative
    },
    text: {
      primary: "#f4f4f4", // Main text color
      secondary: "hsla(0,0%,100%,.5)", // Secondary text color
      disabled: "rgba(255, 255, 255, 0.3)", // Lower contrast for disabled elements
    },
    divider: "rgba(255, 255, 255, 0.12)", // Subtle divider color for better UI separation
    action: {
      hover: "rgba(255, 255, 255, 0.08)",
      selected: "rgba(255, 255, 255, 0.16)",
      disabled: "rgba(255, 255, 255, 0.3)",
    },
  },
  components: {
    MuiPaper: {
      styleOverrides: {
        root: {
          backgroundColor: "#181818",
          color: "#f4f4f4",
        },
      },
    },
    MuiAppBar: {
      styleOverrides: {
        root: {
          backgroundColor: "#181818",
        },
      },
    },
    MuiButton: {
      styleOverrides: {
        root: {
          textTransform: "none",
          borderRadius: "8px",
        },
      },
    },
    MuiTextField: {
      styleOverrides: {
        root: {
          "& label": {
            color: "hsla(0,0%,100%,.5)", // Label text color
          },
          "& label.Mui-focused": {
            color: "#009999", // Focused label color
          },
          "& .MuiOutlinedInput-root": {
            "& fieldset": {
              borderColor: "#444444", // Default border color
            },
            "&:hover fieldset": {
              borderColor: "#009999", // Border color on hover
            },
            "&.Mui-focused fieldset": {
              borderColor: "#009999", // Border color when focused
            },
          },
        },
      },
    },
  },
});

export default theme;
