const webpack = require('webpack');
const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const { config } = require('dotenv');

config({path: '../.env'});

module.exports = {
    entry: './src/index.tsx',
    mode: 'production',
    module: {
        rules: [
            {
                test: /\.tsx?$/,
                use: 'ts-loader',
                exclude: /node_modules/,
            },
            {
                test: /\.scss$/,
                use: [
                    'style-loader',
                    {
                        loader: 'css-loader',
                        options: { sourceMap: true }
                    },
                    {
                        loader: 'sass-loader',
                        options: { sourceMap: true }
                    }
                ]
            },
            {
                test: /\.css$/,
                use: [
                    'style-loader',
                    {
                        loader: 'css-loader',
                        options: { sourceMap: true }
                    }
                ]
            },
        ],
    },
    resolve: {
        extensions: ['.tsx', '.ts', '.js'],
    },
    output: {
        filename: 'bundle.js',
        path: path.resolve(__dirname, 'dist'),
    },
    plugins: [
        new HtmlWebpackPlugin({
            template: './index.html',
        }),
        new HtmlWebpackPlugin({
            filename: 'silent-check-sso.html',
            template: './silent-check-sso.html',
            inject: false,
        }),
        new webpack.DefinePlugin({
            'process.env': {
                KEYCLOAK_URL: JSON.stringify(process.env.KEYCLOAK_FRONTEND_URL),
                KEYCLOAK_REALM: JSON.stringify(process.env.KEYCLOAK_REALM),
                KEYCLOAK_CLIENT: JSON.stringify(process.env.KEYCLOAK_FRONTEND_CLIENT),
             }
         })
    ],
    performance: {
        hints: false,
        maxEntrypointSize: 512000,
        maxAssetSize: 512000
    },
};
